==> codemirror__legacy-modes-6.4.3.jar: META-INF/resources/webjars/codemirror__legacy-modes/6.4.3/CHANGELOG.md <==
## 6.4.3 (2025-02-12)

### Bug fixes

Make Pascal keyword matching case-insensitive.

Fix a crash in simple-mode.js when using the `dontIndentStates` feature.

Fix a bug in tokenizing multiline strings in xQuery.

## 6.4.2 (2024-11-05)

### Bug fixes

Fix an issue in the Groovy mode where interpolated variable style would continue after whitespace.

Add support for underscore separators in numbers in the Dart mode.

## 6.4.1 (2024-08-15)

### Bug fixes

Stop treating closing brackets as brackets in the Common Lisp mode.

Fix a bug where the Stylus mode would crash when queried for indentation.

## 6.4.0 (2024-04-05)

### Bug fixes

Only match Solr operator words when they are upper-case.

Fix an infinite loop when tokenizing heredoc strings in the Crystal mode.

### New features

Add the old Pug mode.

## 6.3.3 (2023-07-20)

### Bug fixes

In Shell mode, don't allow spaces in heredoc tokens.

## 6.3.2 (2023-03-20)

### Bug fixes

Fix tokenizing of character literals in the Scala mode.

## 6.3.1 (2022-11-24)

### Bug fixes

In JavaScript, properly parse keywords like `static` when in front of a private property.

## 6.3.0 (2022-11-18)

### New features

Add the old PegJS mode.

## 6.2.0 (2022-10-24)

### Bug fixes

Include type declarations for mode/simple-mode.js.

### New features

Include a name for each mode in the stream parser objects.

## 6.1.0 (2022-06-17)

### Bug fixes

Add structured concurrency keywords to the Swift mode. Update readme to follow interface changes

### New features

Adds the Sass mode from CodeMirror 5.

## 6.0.0 (2022-06-08)

### Bug fixes

Add line comment syntax metadata to the Toml mode.

## 0.20.0 (2022-04-20)

### Breaking changes

Update dependencies to 0.20.0

## 0.19.1 (2022-03-03)

### Bug fixes

Fix an issue causing the Lua mode to indent everything one unit too far.

Fix a bug in the Swift mode when indenting an empty block after exploding with `insertNewlineAndIndent`.

## 0.19.0 (2021-08-11)

### Breaking changes

Update dependencies to 0.19.0

## 0.18.1 (2021-06-24)

### Bug fixes

Fix internal imports to include the extension in the path.

## 0.18.0 (2021-03-03)

### Breaking changes

Update dependencies to 0.18.

## 0.17.1 (2021-01-06)

### New features

The package now also exports CommonJS modules.

The package now also exports a CommonJS module.

## 0.17.0 (2020-12-29)

### Breaking changes

First numbered release.

==> codemirror__legacy-modes-6.5.0.jar: META-INF/resources/webjars/codemirror__legacy-modes/6.5.0/CHANGELOG.md <==
## 6.5.0 (2025-03-13)

### New features

Simple modes can now include a `mergeTokens` option in their language data to disable token merging.

## 6.4.3 (2025-02-12)

### Bug fixes

Make Pascal keyword matching case-insensitive.

Fix a crash in simple-mode.js when using the `dontIndentStates` feature.

Fix a bug in tokenizing multiline strings in xQuery.

## 6.4.2 (2024-11-05)

### Bug fixes

Fix an issue in the Groovy mode where interpolated variable style would continue after whitespace.

Add support for underscore separators in numbers in the Dart mode.

## 6.4.1 (2024-08-15)

### Bug fixes

Stop treating closing brackets as brackets in the Common Lisp mode.

Fix a bug where the Stylus mode would crash when queried for indentation.

## 6.4.0 (2024-04-05)

### Bug fixes

Only match Solr operator words when they are upper-case.

Fix an infinite loop when tokenizing heredoc strings in the Crystal mode.

### New features

Add the old Pug mode.

## 6.3.3 (2023-07-20)

### Bug fixes

In Shell mode, don't allow spaces in heredoc tokens.

## 6.3.2 (2023-03-20)

### Bug fixes

Fix tokenizing of character literals in the Scala mode.

## 6.3.1 (2022-11-24)

### Bug fixes

In JavaScript, properly parse keywords like `static` when in front of a private property.

## 6.3.0 (2022-11-18)

### New features

Add the old PegJS mode.

## 6.2.0 (2022-10-24)

### Bug fixes

Include type declarations for mode/simple-mode.js.

### New features

Include a name for each mode in the stream parser objects.

## 6.1.0 (2022-06-17)

### Bug fixes

Add structured concurrency keywords to the Swift mode. Update readme to follow interface changes

### New features

Adds the Sass mode from CodeMirror 5.

## 6.0.0 (2022-06-08)

### Bug fixes

Add line comment syntax metadata to the Toml mode.

## 0.20.0 (2022-04-20)

### Breaking changes

Update dependencies to 0.20.0

## 0.19.1 (2022-03-03)

### Bug fixes

Fix an issue causing the Lua mode to indent everything one unit too far.

Fix a bug in the Swift mode when indenting an empty block after exploding with `insertNewlineAndIndent`.

## 0.19.0 (2021-08-11)

### Breaking changes

Update dependencies to 0.19.0

## 0.18.1 (2021-06-24)

### Bug fixes

Fix internal imports to include the extension in the path.

## 0.18.0 (2021-03-03)

### Breaking changes

Update dependencies to 0.18.

## 0.17.1 (2021-01-06)

### New features

The package now also exports CommonJS modules.

The package now also exports a CommonJS module.

## 0.17.0 (2020-12-29)

### Breaking changes

First numbered release.
